package com.adzel.addyauthreborn.auth;

import java.util.Set;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

import at.favre.lib.crypto.bcrypt.BCrypt;

public class AuthManager {

    private final AuthStorage storage;
    private final Set<UUID> lockedPlayers = ConcurrentHashMap.newKeySet();

    public AuthManager() {
        this.storage = new AuthStorage(); // will handle DB interactions
    }

    public boolean isRegistered(UUID uuid) {
        return storage.isRegistered(uuid);
    }

    public boolean registerPassword(UUID uuid, String plainPassword) {
        if (isRegistered(uuid)) return false;

        String hash = BCrypt.withDefaults().hashToString(12, plainPassword.toCharArray());
        return storage.savePassword(uuid, hash);
    }

    public boolean verifyPassword(UUID uuid, String attempt) {
        String hash = storage.getPasswordHash(uuid);
        if (hash != null) {
            BCrypt.Result result = BCrypt.verifyer().verify(attempt.toCharArray(), hash);
            if (result.verified) {
                unlock(uuid); // unlock on successful login
                return true;
            }
        }
        return false;
    }

    public void lock(UUID uuid) {
        lockedPlayers.add(uuid);
        storage.setLastLockTime(uuid, System.currentTimeMillis());
    }

    public void unlock(UUID uuid) {
        lockedPlayers.remove(uuid);
    }

    public boolean isLocked(UUID uuid) {
        return lockedPlayers.contains(uuid);
    }

    public long getLastLockTime(UUID uuid) {
        return storage.getLastLockTime(uuid);
    }

    public AuthStorage getStorage() {
        return storage;
    }
}
