package com.adzel.addyauthreborn.auth;

import com.adzel.addyauthreborn.AddyAuthReborn;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.UUID;

public class AuthStorage {

    private final AddyAuthReborn plugin = AddyAuthReborn.getInstance();

    public AuthStorage() {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "CREATE TABLE IF NOT EXISTS addyauth_users (" +
                "uuid VARCHAR(36) PRIMARY KEY," +
                "password_hash TEXT NOT NULL," +
                "last_locked_at BIGINT DEFAULT 0)"
            );
            ps.executeUpdate();
            ps.close();
        } catch (SQLException e) {
            plugin.getLogger().severe("Failed to create users table: " + e.getMessage());
        }
    }

    public boolean isRegistered(UUID uuid) {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "SELECT uuid FROM addyauth_users WHERE uuid = ?"
            );
            ps.setString(1, uuid.toString());
            ResultSet rs = ps.executeQuery();
            boolean exists = rs.next();
            rs.close();
            ps.close();
            return exists;
        } catch (SQLException e) {
            plugin.getLogger().warning("Failed to check registration: " + e.getMessage());
            return false;
        }
    }

    public boolean savePassword(UUID uuid, String hashedPassword) {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "INSERT INTO addyauth_users (uuid, password_hash) VALUES (?, ?)"
            );
            ps.setString(1, uuid.toString());
            ps.setString(2, hashedPassword);
            ps.executeUpdate();
            ps.close();
            return true;
        } catch (SQLException e) {
            plugin.getLogger().warning("Failed to save password: " + e.getMessage());
            return false;
        }
    }

    public String getPasswordHash(UUID uuid) {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "SELECT password_hash FROM addyauth_users WHERE uuid = ?"
            );
            ps.setString(1, uuid.toString());
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                String hash = rs.getString("password_hash");
                rs.close();
                ps.close();
                return hash;
            }
            rs.close();
            ps.close();
        } catch (SQLException e) {
            plugin.getLogger().warning("Failed to retrieve password hash: " + e.getMessage());
        }
        return null;
    }

    public boolean setLastLockTime(UUID uuid, long timestamp) {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "UPDATE addyauth_users SET last_locked_at = ? WHERE uuid = ?"
            );
            ps.setLong(1, timestamp);
            ps.setString(2, uuid.toString());
            int updated = ps.executeUpdate();
            ps.close();
            return updated > 0;
        } catch (SQLException e) {
            plugin.getLogger().warning("Failed to update last lock time: " + e.getMessage());
            return false;
        }
    }

    public long getLastLockTime(UUID uuid) {
        try (Connection conn = plugin.getDataSource().getConnection()) {
            PreparedStatement ps = conn.prepareStatement(
                "SELECT last_locked_at FROM addyauth_users WHERE uuid = ?"
            );
            ps.setString(1, uuid.toString());
            ResultSet rs = ps.executeQuery();
            if (rs.next()) {
                long timestamp = rs.getLong("last_locked_at");
                rs.close();
                ps.close();
                return timestamp;
            }
            rs.close();
            ps.close();
        } catch (SQLException e) {
            plugin.getLogger().warning("Failed to fetch last lock time: " + e.getMessage());
        }
        return 0;
    }
}
