package com.adzel.addyauthreborn.commands;

import com.adzel.addyauthreborn.AddyAuthReborn;
import com.adzel.addyauthreborn.utils.MessageUtil;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;

public class RegisterCommand implements CommandExecutor {

    private final AddyAuthReborn plugin;

    public RegisterCommand(AddyAuthReborn plugin) {
        this.plugin = plugin;
    }

    @Override
    public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {
        if (!(sender instanceof Player player)) {
            sender.sendMessage("Only players can use this command.");
            return true;
        }

        if (!player.hasPermission("addyauth.register")) {
            MessageUtil.send(player, "&cYou do not have permission to register.");
            return true;
        }

        if (args.length != 1) {
            MessageUtil.send(player, "&cUsage: /register <password>");
            return true;
        }

        String password = args[0];
        int minLength = plugin.getMinPasswordLength();
        int maxLength = plugin.getMaxPasswordLength();

        if (password.length() < minLength || password.length() > maxLength) {
            MessageUtil.send(player, "&cPassword must be between " + minLength + " and " + maxLength + " characters.");
            return true;
        }

        if (plugin.getAuthManager().isRegistered(player.getUniqueId())) {
            MessageUtil.send(player, "&eYou are already registered.");
            return true;
        }

        boolean success = plugin.getAuthManager().registerPassword(player.getUniqueId(), password);
        if (success) {
            MessageUtil.send(player, "&aYour password has been registered successfully.");
        } else {
            MessageUtil.send(player, "&cSomething went wrong. Please try again.");
        }

        return true;
    }
}
