package com.adzel.addyauthreborn.listeners;

import com.adzel.addyauthreborn.AddyAuthReborn;
import com.adzel.addyauthreborn.utils.MessageUtil;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.event.player.*;

public class LockListeners implements Listener {

    private final AddyAuthReborn plugin;

    public LockListeners(AddyAuthReborn plugin) {
        this.plugin = plugin;
    }

    private boolean isLocked(Player player) {
        return plugin.getAuthManager().isLocked(player.getUniqueId());
    }

    private void updateIfNotLocked(Player player) {
        if (!isLocked(player)) {
            plugin.getAFKMonitor().updateActivity(player.getUniqueId());
        }
    }

    @EventHandler
    public void onMove(PlayerMoveEvent event) {
        Player player = event.getPlayer();
        if (isLocked(player) && event.getFrom().distanceSquared(event.getTo()) > 0) {
            event.setCancelled(true);
        } else if (event.getFrom().distanceSquared(event.getTo()) > 1) {
            updateIfNotLocked(player);
        }
    }

    @EventHandler
    public void onChat(AsyncPlayerChatEvent event) {
        Player player = event.getPlayer();
        if (isLocked(player)) {
            event.setCancelled(true);
            MessageUtil.send(player, "&cYou cannot chat while locked.");
        } else {
            updateIfNotLocked(player);
        }
    }

    @EventHandler
    public void onClick(InventoryClickEvent event) {
        if (event.getWhoClicked() instanceof Player player) {
            if (isLocked(player)) {
                event.setCancelled(true);
            } else {
                updateIfNotLocked(player);
            }
        }
    }

    @EventHandler
    public void onDrop(PlayerDropItemEvent event) {
        Player player = event.getPlayer();
        if (isLocked(player)) {
            event.setCancelled(true);
        } else {
            updateIfNotLocked(player);
        }
    }

    @EventHandler
    public void onPickup(PlayerAttemptPickupItemEvent event) {
        Player player = event.getPlayer();
        if (isLocked(player)) {
            event.setCancelled(true);
        } else {
            updateIfNotLocked(player);
        }
    }

    @EventHandler
    public void onInteract(PlayerInteractEvent event) {
        Player player = event.getPlayer();
        if (isLocked(player)) {
            event.setCancelled(true);
        } else {
            updateIfNotLocked(player);
        }
    }
}
