package com.adzel.addyauthreborn.lock;

import java.util.Map;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

import org.bukkit.Bukkit;
import org.bukkit.entity.Player;
import org.bukkit.scheduler.BukkitRunnable;

import com.adzel.addyauthreborn.AddyAuthReborn;
import com.adzel.addyauthreborn.utils.MessageUtil;

public class AFKMonitor {

    private final AddyAuthReborn plugin;
    private final Map<UUID, Long> lastActivityMap = new ConcurrentHashMap<>();
    private final long timeoutMillis;
    private final boolean enabled;
    private BukkitRunnable monitorTask;

    public AFKMonitor(AddyAuthReborn plugin) {
        this.plugin = plugin;
        this.enabled = plugin.getConfig().getBoolean("Time Based Settings.AFK Lock.Enabled", true);
        this.timeoutMillis = plugin.getConfig().getLong("Time Based Settings.AFK Lock.Auto Lock", 30) * 60 * 1000L;

        if (enabled) {
            startMonitor();
        }
    }

    public void updateActivity(UUID uuid) {
        lastActivityMap.put(uuid, System.currentTimeMillis());
    }

    public void remove(UUID uuid) {
        lastActivityMap.remove(uuid);
    }

    public void removePlayer(UUID uuid) {
        lastActivityMap.remove(uuid);
    }

    private void startMonitor() {
        monitorTask = new BukkitRunnable() {
            @Override
            public void run() {
                long now = System.currentTimeMillis();

                for (Player player : Bukkit.getOnlinePlayers()) {
                    UUID uuid = player.getUniqueId();

                    if (!plugin.getAuthManager().isRegistered(uuid)) continue;
                    if (plugin.getAuthManager().isLocked(uuid)) continue;

                    long lastActive = lastActivityMap.getOrDefault(uuid, now);
                    if ((now - lastActive) >= timeoutMillis) {
                        plugin.getAuthManager().lock(uuid); // ✅ Stores timestamp
                        MessageUtil.send(player, "&cYou have been locked due to AFK timeout.");
                    }
                }
            }
        };
        monitorTask.runTaskTimer(plugin, 20L * 60, 20L * 60); // every 60 seconds
    }

    public void shutdown() {
        if (monitorTask != null) {
            monitorTask.cancel();
        }
        lastActivityMap.clear();
    }
}
