package com.adzel.addyauthreborn.lock;

import com.adzel.addyauthreborn.AddyAuthReborn;

import java.util.Map;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;

public class OfflineLockManager {

    private final AddyAuthReborn plugin;
    private final Map<UUID, Long> logoutTimestamps = new ConcurrentHashMap<>();
    private final long offlineThresholdMillis;

    public OfflineLockManager(AddyAuthReborn plugin) {
        this.plugin = plugin;
        long minutes = plugin.getConfig().getLong("Time Based Settings.Offline Lock.Auto Lock", 120);
        this.offlineThresholdMillis = minutes * 60_000;
    }

    public void recordLogout(UUID uuid) {
        logoutTimestamps.put(uuid, System.currentTimeMillis());
    }

    public void evaluateLogin(UUID uuid) {
        if (!plugin.getConfig().getBoolean("Time Based Settings.Offline Lock.Enabled", true)) return;

        Long logoutTime = logoutTimestamps.get(uuid);
        if (logoutTime == null) return;

        long elapsed = System.currentTimeMillis() - logoutTime;
        if (elapsed >= offlineThresholdMillis) {
            plugin.getAuthManager().lock(uuid); // ✅ Stores timestamp
        }
    }

    public void forget(UUID uuid) {
        logoutTimestamps.remove(uuid);
    }
}
