package com.adzel.addyauthreborn.updates;

import com.adzel.addyauthreborn.AddyAuthReborn;

import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.function.Consumer;

public class UpdateChecker {

    private final AddyAuthReborn plugin;
    private final String apiUrl;

    public UpdateChecker(AddyAuthReborn plugin, String apiUrl) {
        this.plugin = plugin;
        this.apiUrl = apiUrl;
    }

    public void getLatestVersion(Consumer<String> callback) {
        plugin.getServer().getScheduler().runTaskAsynchronously(plugin, () -> {
            try {
                // Gitea's latest release endpoint returns a JSON object
                URL url = new URL(apiUrl);
                HttpURLConnection connection = (HttpURLConnection) url.openConnection();
                connection.setRequestProperty("Accept", "application/json");
                connection.setConnectTimeout(5000);
                connection.setReadTimeout(5000);

                if (connection.getResponseCode() != 200) {
                    plugin.getLogger().warning("Update check failed: Invalid response from Gitea (" + connection.getResponseCode() + ")");
                    return;
                }

                BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
                StringBuilder json = new StringBuilder();
                String line;
                while ((line = reader.readLine()) != null) {
                    json.append(line);
                }
                reader.close();

                String latest = parseTagName(json.toString());
                if (latest != null) {
                    callback.accept(latest);
                } else {
                    plugin.getLogger().warning("Update check failed: Could not parse latest tag.");
                }

            } catch (Exception e) {
                plugin.getLogger().warning("Update check failed: " + e.getMessage());
            }
        });
    }

    private String parseTagName(String json) {
        // crude but fast — this works with Gitea’s /releases/latest API
        String key = "\"tag_name\":\"";
        int index = json.indexOf(key);
        if (index == -1) return null;

        int start = index + key.length();
        int end = json.indexOf("\"", start);
        return end == -1 ? null : json.substring(start, end);
    }
}