package com.adzel.addyauthreborn.utils;

import com.adzel.addyauthreborn.AddyAuthReborn;
import com.zaxxer.hikari.HikariConfig;
import com.zaxxer.hikari.HikariDataSource;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.Statement;

public class DatabaseUtil {

    private static HikariDataSource dataSource;

    public static boolean initDatabase() {
        AddyAuthReborn plugin = AddyAuthReborn.getInstance();

        String type = plugin.getConfig().getString("Database.Type", "sqlite").toLowerCase();
        HikariConfig config = new HikariConfig();

        try {
            switch (type) {
                case "mysql":
                case "mariadb":
                    config.setJdbcUrl("jdbc:mariadb://" +
                            plugin.getConfig().getString("Database.Host", "localhost") + ":" +
                            plugin.getConfig().getInt("Database.Port", 3306) + "/" +
                            plugin.getConfig().getString("Database.Name", "addyauth"));
                    config.setUsername(plugin.getConfig().getString("Database.Username", "root"));
                    config.setPassword(plugin.getConfig().getString("Database.Password", ""));
                    config.setDriverClassName("org.mariadb.jdbc.Driver");
                    break;

                case "sqlite":
                default:
                    config.setJdbcUrl("jdbc:sqlite:" + plugin.getDataFolder() + "/addyauth.db");
                    config.setDriverClassName("org.sqlite.JDBC");
                    break;
            }

            config.setMaximumPoolSize(5);
            config.setPoolName("AddyAuthPool");
            dataSource = new HikariDataSource(config);

            try (Connection conn = dataSource.getConnection()) {
                createTables(conn);
            }

            return true;

        } catch (Exception e) {
            plugin.getLogger().severe("Database initialization failed: " + e.getMessage());
            return false;
        }
    }

    private static void createTables(Connection conn) throws SQLException {
        try (Statement stmt = conn.createStatement()) {
            stmt.executeUpdate("""
                CREATE TABLE IF NOT EXISTS addyauth_users (
                    uuid VARCHAR(36) PRIMARY KEY,
                    password_hash TEXT NOT NULL,
                    last_locked_at BIGINT DEFAULT 0
                )
            """);
        }
    }

    public static HikariDataSource getDataSource() {
        return dataSource;
    }

    public static void shutdown() {
        if (dataSource != null && !dataSource.isClosed()) {
            dataSource.close();
        }
    }
}
